@@ -24,7 +24,6 @@ import time
 import xml.sax.saxutils
 from gi.repository import GObject, Pango, PangoCairo, Gdk, Gtk, Gedit
 from signals import Signals
-import constants
 import gettext
 from gpdefs import *
 
@@ -38,7 +37,7 @@ class DocumentHelper(Signals):
     def __init__(self, view):
         Signals.__init__(self)
 
-        view.set_data(constants.DOCUMENT_HELPER_KEY, self)
+        view.multiedit_document_helper = self
 
         self._view = view
         self._buffer = None
@@ -115,6 +114,7 @@ class DocumentHelper(Signals):
             return
 
         if newbuf != None:
+            self.connect_signal(newbuf, 'insert-text', self.on_insert_text_before)
             self.connect_signal_after(newbuf, 'insert-text', self.on_insert_text)
 
             self.connect_signal(newbuf, 'delete-range', self.on_delete_range_before)
@@ -135,7 +135,7 @@ class DocumentHelper(Signals):
         self._cancel_column_mode()
         self.reset_buffer(None)
 
-        self._view.set_data(constants.DOCUMENT_HELPER_KEY, None)
+        self._view.multiedit_document_helper = None
 
         self.disconnect_signals(self._view)
         self._view = None
@@ -157,7 +157,7 @@ class DocumentHelper(Signals):
             [('Return',), Gdk.ModifierType.CONTROL_MASK | Gdk.ModifierType.SHIFT_MASK | Gdk.ModifierType.MOD1_MASK, self.do_smart_column_align, True],
             [('Home',), Gdk.ModifierType.CONTROL_MASK, self.do_mark_start, True],
             [('End',), Gdk.ModifierType.CONTROL_MASK, self.do_mark_end, True],
-            [('e',), Gdk.ModifierType.CONTROL_MASK, self.do_toggle_edit_point, True]
+            [('e', 'E'), Gdk.ModifierType.CONTROL_MASK, self.do_toggle_edit_point, True]
         ]
 
         for handler in self._event_handlers:
@@ -778,12 +778,16 @@ class DocumentHelper(Signals):
     def on_notify_buffer(self, view, spec):
         self.reset_buffer(view.get_buffer())
 
-    def on_insert_text(self, buf, where, text, length):
+    def on_insert_text_before(self, buf, where, text, length):
         if not self._in_mode:
             return
 
         self._remove_duplicate_edit_points()
 
+    def on_insert_text(self, buf, where, text, length):
+        if not self._in_mode:
+            return
+
         self.block_signal(buf, 'insert-text')
         buf.begin_user_action()
 
@@ -963,8 +967,8 @@ class DocumentHelper(Signals):
 
         text = self._column_text()
 
-        clipboard = Gtk.Clipboard(self._view.get_display())
-        clipboard.set_text(text)
+        clipboard = Gtk.Clipboard.get_for_display(self._view.get_display(), Gdk.SELECTION_CLIPBOARD)
+        clipboard.set_text(text, -1)
 
         view.stop_emission('copy-clipboard')
 
@@ -973,8 +977,9 @@ class DocumentHelper(Signals):
             return
 
         text = self._column_text()
-        clipboard = Gtk.Clipboard(self._view.get_display())
-        clipboard.set_text(text)
+
+        clipboard = Gtk.Clipboard.get_for_display(self._view.get_display(), Gdk.SELECTION_CLIPBOARD)
+        clipboard.set_text(text, -1)
 
         view.stop_emission('cut-clipboard')
 
@@ -1031,7 +1036,7 @@ class DocumentHelper(Signals):
         clipboard = Gtk.Clipboard.get_for_display(self._view.get_display(), Gdk.SELECTION_CLIPBOARD)
         self._paste_mark = self._buffer.create_mark(None, self._buffer.get_iter_at_mark(self._buffer.get_insert()), True)
 
-        clipboard.request_text(self.on_clipboard_text)
+        clipboard.request_text(self.on_clipboard_text, None)
         view.stop_emission('paste-clipboard')
 
     def _move_edit_points(self, buf, where):
